@@ -39,15 +39,15 @@ impl<'lock> Audit<'lock> {
         };
         let secondary_locations = Vec::new();
         sonar::Issue {
-            engine_id: AUDIT_ENGINE.to_string(),
+            engine_id: AUDIT_ENGINE.to_owned(),
             rule_id,
             severity: sonar::Severity::Major,
-            r#type: sonar::IssueType::Vulnerability,
+            r#type: sonar::Type::Vulnerability,
             primary_location,
             secondary_locations,
         }
     }
-    pub fn to_issues(&self, report: Report) -> sonar::Report {
+    pub fn to_issues(&self, report: Report) -> sonar::Issues {
         report
             .vulnerabilities
             .list
@@ -57,10 +57,10 @@ impl<'lock> Audit<'lock> {
     }
 }
 
-impl std::convert::TryInto<sonar::Report> for Audit<'_> {
+impl std::convert::TryInto<sonar::Issues> for Audit<'_> {
     type Error = eyre::Error;
 
-    fn try_into(self) -> Result<sonar::Report> {
+    fn try_into(self) -> Result<sonar::Issues> {
         let file = File::open(&self.json).with_context(|| {
             format!(
                 "failed to open 'cargo-audit' report from '{:?}' file",
