@@ -70,11 +70,13 @@ impl TryFrom<&Path> for Lockfile {
         let reader = BufReader::new(file);
         let mut state = StateParser::End;
         for (line_num, line) in reader.lines().enumerate() {
-            let line_num = line_num + 1;
+            let line_num = line_num.saturating_add(1);
             let line = line?;
             let create_range = |line: &str| {
                 let start_column = line.find('"').unwrap_or(0);
-                let end_column = line.rfind('"').unwrap_or_else(|| line.len() - 1);
+                let end_column = line
+                    .rfind('"')
+                    .unwrap_or_else(|| line.len().saturating_sub(1));
                 TextRange {
                     start_line: line_num,
                     end_line: line_num,
