@@ -29,7 +29,7 @@ pub enum Error {
 
 impl From<&DiagnosticLevel> for sonar::Severity {
     fn from(level: &DiagnosticLevel) -> Self {
-        match level {
+        match *level {
             DiagnosticLevel::Ice => sonar::Severity::Blocker,
             DiagnosticLevel::Error => sonar::Severity::Critical,
             DiagnosticLevel::Warning => sonar::Severity::Major,
@@ -54,6 +54,9 @@ impl From<&DiagnosticSpan> for sonar::TextRange {
     }
 }
 
+// ALLOW: 'CompilerMessage' has already been ruled out above,
+// so this will never panic
+#[allow(clippy::panic_in_result_fn)]
 impl TryFrom<Message> for sonar::Issue {
     type Error = Error;
     fn try_from(message: Message) -> Result<Self, Self::Error> {
@@ -63,11 +66,11 @@ impl TryFrom<Message> for sonar::Issue {
                 |diagnostic_code| diagnostic_code.code.clone(),
             );
             let severity = sonar::Severity::from(&message.message.level);
-            let r#type = sonar::IssueType::CodeSmell;
+            let r#type = sonar::Type::CodeSmell;
             let (primary_location, secondary_locations) = match message.message.spans.len() {
                 0 => return Err(Error::NoSpan),
                 n => {
-                    let span = &message.message.spans[0];
+                    let span = message.message.spans.get(0).ok_or(Error::NoSpan)?;
                     let primary_location = sonar::Location {
                         message: message.message.message.clone(),
                         file_path: span.file_name.clone(),
@@ -85,7 +88,7 @@ impl TryFrom<Message> for sonar::Issue {
                 }
             };
             let issue = Self {
-                engine_id: CLIPPY_ENGINE.to_string(),
+                engine_id: CLIPPY_ENGINE.to_owned(),
                 rule_id,
                 severity,
                 r#type,
@@ -118,10 +121,10 @@ impl Clippy {
     }
 }
 
-impl std::convert::TryInto<sonar::Report> for Clippy {
+impl std::convert::TryInto<sonar::Issues> for Clippy {
     type Error = eyre::Error;
 
-    fn try_into(self) -> Result<sonar::Report, Self::Error> {
+    fn try_into(self) -> Result<sonar::Issues, Self::Error> {
         let file = File::open(&self.json).with_context(|| {
             format!(
                 "failed to open 'cargo-clippy' report from '{:?}' file",
@@ -129,7 +132,7 @@ impl std::convert::TryInto<sonar::Report> for Clippy {
             )
         })?;
         let reader = BufReader::new(file);
-        let issues: sonar::Report = reader
+        let issues: sonar::Issues = reader
             .lines()
             .flatten()
             .flat_map(|line| serde_json::from_str::<cargo_metadata::Message>(&line))
